@@ -1,7 +1,4 @@
 phasePlot1D <- function(curtab, odes, state, parms, plotopts, numopts) {
-  # Save plot options to restore on exit
-  oldpar <- par(no.readonly = TRUE)
-  on.exit(par(oldpar))
 
   x <- 1
   xmin <- as.numeric(plotopts$xmin)
